==> gwt-openlayers-client-0.9.jar: org/gwtopenmaps/openlayers/client/geometry/LinearRing.java <==
/**
 *
 *   Copyright 2013 sourceforge.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.gwtopenmaps.openlayers.client.geometry;

import org.gwtopenmaps.openlayers.client.util.JObjectArray;
import org.gwtopenmaps.openlayers.client.util.JSObject;


/**
 * @author Edwin Commandeur - Atlis EJS
 *
 */
public class LinearRing extends LineString
{

    public static LinearRing narrowToLinearRing(JSObject linearRing)
    {
        return (linearRing == null) ? null : new LinearRing(linearRing);
    }

    public static LinearRing fromCoordinateArray(double[][] coordinateArray)
    {
        int max = coordinateArray.length;
        Point[] pts = new Point[max];
        for (int i = 0; i < max; i++)
        {
            Point p = new Point(coordinateArray[i][0], coordinateArray[i][1]);
            pts[i] = p;
        }

        LinearRing ring = new LinearRing(pts);

        return ring;
    }

    protected LinearRing(JSObject linearRing)
    {
        super(linearRing);
    }

    public LinearRing(Point[] pts)
    {
        this(LinearRingImpl.create((new JObjectArray(pts).getJSObject())));
    }
}

==> gwt-openlayers-client-1.0.jar: org/gwtopenmaps/openlayers/client/geometry/LinearRing.java <==
/**
 *
 *   Copyright 2014 sourceforge.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.gwtopenmaps.openlayers.client.geometry;

import org.gwtopenmaps.openlayers.client.util.JObjectArray;
import org.gwtopenmaps.openlayers.client.util.JSObject;

/**
 * @author Edwin Commandeur - Atlis EJS
 *
 */
public class LinearRing extends LineString {

    public static LinearRing narrowToLinearRing(JSObject linearRing) {
        return (linearRing == null) ? null : new LinearRing(linearRing);
    }

    public static LinearRing fromCoordinateArray(double[][] coordinateArray) {
        int max = coordinateArray.length;
        Point[] pts = new Point[max];
        for (int i = 0; i < max; i++) {
            Point p = new Point(coordinateArray[i][0], coordinateArray[i][1]);
            pts[i] = p;
        }

        LinearRing ring = new LinearRing(pts);

        return ring;
    }

    protected LinearRing(JSObject linearRing) {
        super(linearRing);
    }

    public LinearRing(Point[] pts) {
        this(LinearRingImpl.create((new JObjectArray(pts).getJSObject())));
    }

}
